---
name: Feature request
about: Suggest a new idea
title: '[FEATURE]'
labels: ''
assignees: matteosox

---

## What seems to be the problem here? 🐛
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

## Proposed solution 👩‍💻
A clear and concise description of what you want to happen.

## Alternatives 🚧
A clear and concise description of any alternative solutions or features you've considered.

## Additional context ✨
Add any other context or screenshots about the feature request here.
